summaryrefslogtreecommitdiff
path: root/lib/Target/Sparc
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2009-08-22 20:48:53 +0000
committerChris Lattner <sabre@nondot.org>2009-08-22 20:48:53 +0000
commitaf76e592c7f9deff0e55c13dbb4a34f07f1c7f64 (patch)
tree7a9d9824fa8735ec1a2eed14653689ce31b567a1 /lib/Target/Sparc
parent9c52affd374e20b212d3266050f13d87ba80e36d (diff)
downloadllvm-af76e592c7f9deff0e55c13dbb4a34f07f1c7f64.tar.gz
llvm-af76e592c7f9deff0e55c13dbb4a34f07f1c7f64.tar.bz2
llvm-af76e592c7f9deff0e55c13dbb4a34f07f1c7f64.tar.xz
Rename TargetAsmInfo (and its subclasses) to MCAsmInfo.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@79763 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Target/Sparc')
-rw-r--r--lib/Target/Sparc/AsmPrinter/SparcAsmPrinter.cpp4
-rw-r--r--lib/Target/Sparc/SparcMCAsmInfo.cpp (renamed from lib/Target/Sparc/SparcTargetAsmInfo.cpp)9
-rw-r--r--lib/Target/Sparc/SparcMCAsmInfo.h (renamed from lib/Target/Sparc/SparcTargetAsmInfo.h)10
-rw-r--r--lib/Target/Sparc/SparcTargetMachine.cpp4
4 files changed, 13 insertions, 14 deletions
diff --git a/lib/Target/Sparc/AsmPrinter/SparcAsmPrinter.cpp b/lib/Target/Sparc/AsmPrinter/SparcAsmPrinter.cpp
index d39b6efa3e..663315e2eb 100644
--- a/lib/Target/Sparc/AsmPrinter/SparcAsmPrinter.cpp
+++ b/lib/Target/Sparc/AsmPrinter/SparcAsmPrinter.cpp
@@ -25,7 +25,7 @@
#include "llvm/CodeGen/MachineConstantPool.h"
#include "llvm/CodeGen/MachineInstr.h"
#include "llvm/MC/MCStreamer.h"
-#include "llvm/Target/TargetAsmInfo.h"
+#include "llvm/MC/MCAsmInfo.h"
#include "llvm/Target/TargetLoweringObjectFile.h"
#include "llvm/Target/TargetRegistry.h"
#include "llvm/ADT/Statistic.h"
@@ -53,7 +53,7 @@ namespace {
unsigned BBNumber;
public:
explicit SparcAsmPrinter(formatted_raw_ostream &O, TargetMachine &TM,
- const TargetAsmInfo *T, bool V)
+ const MCAsmInfo *T, bool V)
: AsmPrinter(O, TM, T, V), BBNumber(0) {}
virtual const char *getPassName() const {
diff --git a/lib/Target/Sparc/SparcTargetAsmInfo.cpp b/lib/Target/Sparc/SparcMCAsmInfo.cpp
index 1794ebc587..e9d1c38f82 100644
--- a/lib/Target/Sparc/SparcTargetAsmInfo.cpp
+++ b/lib/Target/Sparc/SparcMCAsmInfo.cpp
@@ -1,4 +1,4 @@
-//===-- SparcTargetAsmInfo.cpp - Sparc asm properties ---------------------===//
+//===-- SparcMCAsmInfo.cpp - Sparc asm properties -------------------------===//
//
// The LLVM Compiler Infrastructure
//
@@ -7,16 +7,15 @@
//
//===----------------------------------------------------------------------===//
//
-// This file contains the declarations of the SparcTargetAsmInfo properties.
+// This file contains the declarations of the SparcMCAsmInfo properties.
//
//===----------------------------------------------------------------------===//
-#include "SparcTargetAsmInfo.h"
+#include "SparcMCAsmInfo.h"
#include "llvm/ADT/SmallVector.h"
using namespace llvm;
-SparcELFTargetAsmInfo::SparcELFTargetAsmInfo(const Target &T,
- const StringRef &TT) {
+SparcELFMCAsmInfo::SparcELFMCAsmInfo(const Target &T, const StringRef &TT) {
Data16bitsDirective = "\t.half\t";
Data32bitsDirective = "\t.word\t";
Data64bitsDirective = 0; // .xword is only supported by V9.
diff --git a/lib/Target/Sparc/SparcTargetMachine.cpp b/lib/Target/Sparc/SparcTargetMachine.cpp
index 505e2b11d5..3a381151f9 100644
--- a/lib/Target/Sparc/SparcTargetMachine.cpp
+++ b/lib/Target/Sparc/SparcTargetMachine.cpp
@@ -10,7 +10,7 @@
//
//===----------------------------------------------------------------------===//
-#include "SparcTargetAsmInfo.h"
+#include "SparcMCAsmInfo.h"
#include "SparcTargetMachine.h"
#include "Sparc.h"
#include "llvm/PassManager.h"
@@ -20,7 +20,7 @@ using namespace llvm;
extern "C" void LLVMInitializeSparcTarget() {
// Register the target.
RegisterTargetMachine<SparcTargetMachine> X(TheSparcTarget);
- RegisterAsmInfo<SparcELFTargetAsmInfo> Y(TheSparcTarget);
+ RegisterAsmInfo<SparcELFMCAsmInfo> Y(TheSparcTarget);
}
diff --git a/lib/Target/Sparc/SparcTargetAsmInfo.h b/lib/Target/Sparc/SparcMCAsmInfo.h
index edf8146242..12d6ef4a6f 100644
--- a/lib/Target/Sparc/SparcTargetAsmInfo.h
+++ b/lib/Target/Sparc/SparcMCAsmInfo.h
@@ -1,4 +1,4 @@
//=====-- SparcTargetAsmInfo.h - Sparc asm properties ---------*- C++ -*--====//
//
// The LLVM Compiler Infrastructure
//
@@ -7,20 +7,20 @@
//
//===----------------------------------------------------------------------===//
//
// This file contains the declaration of the SparcTargetAsmInfo class.
//
//===----------------------------------------------------------------------===//
#ifndef SPARCTARGETASMINFO_H
#define SPARCTARGETASMINFO_H
-#include "llvm/Target/TargetAsmInfo.h"
+#include "llvm/MC/MCAsmInfo.h"
namespace llvm {
class Target;
class StringRef;
- struct SparcELFTargetAsmInfo : public TargetAsmInfo {
- explicit SparcELFTargetAsmInfo(const Target &T, const StringRef &TT);
+ struct SparcELFMCAsmInfo : public MCAsmInfo {
+ explicit SparcELFMCAsmInfo(const Target &T, const StringRef &TT);
};
} // namespace llvm
@@ -1,4 +1,4 @@
-//=====-- SparcTargetAsmInfo.h - Sparc asm properties ---------*- C++ -*--====//
+//=====-- SparcMCAsmInfo.h - Sparc asm properties -------------*- C++ -*--====//
//
// The LLVM Compiler Infrastructure
@@ -7,20 +7,20 @@
//===----------------------------------------------------------------------===//
//
-// This file contains the declaration of the SparcTargetAsmInfo class.
+// This file contains the declaration of the SparcMCAsmInfo class.
//
//===----------------------------------------------------------------------===//